import logging
import pytest

from config import NOMICS_API_KEY
from nomics import Nomics

@pytest.fixture
def nomics():
    return Nomics(NOMICS_API_KEY)

def test_get_rates(nomics):
    data = nomics.ExchangeRates.get_rates()
    assert isinstance(data, list)
    assert len(data) > 0

def test_get_history(nomics):
    data = nomics.ExchangeRates.get_history(
        currency = "ETH",
        start = "2018-04-14T00:00:00Z"
    )
    assert isinstance(data, list)
    assert len(data) > 0


import requests

from .api import API

class Candles(API):
    def get_candles(self, interval, base, quote = None, exchange = None, start = None, end = None, format = None):
        '''
        Returns aggregated open, high, low, close, and volume information for Nomics currencies. 
        If only base is provided then OHLCV values are returned in USD. 
        If both base and quote are provided, then OHLC values are returned in the quote currency and volume is returned in base currency. 
        If exchange is provided, candles are provided for only that exchange.

        :param  str interval:   Time interval of the candle

        :param  str base:       Base currency of the pair 

        :param  str quote:      Quote currency of the pair   

        :param  str exchange:   Exchange ID 

        :param  str start:      Start time of the interval in RFC3339 format

        :param  str end:        End time of the interval in RFC3339 format.

        :param  str format:     Format of the response. Defaults to JSON when blank.   

        '''

        params = {
            'interval': interval,
            'start': start,
            'end': end,
            'format': format
        }

        if exchange:
            url = self.client.get_url('exchange_candles')
            params['exchange'] = exchange
            params['market'] = base + quote

        elif base and quote:
            url = self.client.get_url('markets/candles')
            params['base'] = base
            params['quote'] = quote

        else:
            url = self.client.get_url('candles')
            params['currency'] = base

        resp = requests.get(url, params = params)

        if resp.status_code == 200:
            return resp.json()
        else:
            return resp.text


import logging
import pytest

from config import NOMICS_API_KEY
from nomics import Nomics

@pytest.fixture
def nomics():
    return Nomics(NOMICS_API_KEY)

def test_get_markets(nomics):
    data = nomics.Markets.get_markets(exchange = 'binance')
    assert isinstance(data, list)
    assert len(data) > 0

def test_get_market_cap_history(nomics):
    data = nomics.Markets.get_market_cap_history(start = "2018-04-14T00:00:00Z")
    assert isinstance(data, list)
    assert len(data) > 0

def test_get_exchange_markets_ticker(nomics):
    data = nomics.Markets.get_exchange_markets_ticker(exchange = 'binance')
    assert isinstance(data, list)
    assert len(data) > 0


import requests

from .api import API

class Markets(API):
    def get_markets(self, exchange = None, base = None, quote = None):
        '''
        Returns information on the exchanges and markets that Nomics supports

        :param  str     exchange:   Nomics Exchange ID to filter by
                                    Optional   

        :param  [str]   base:       Comma separated list of base currencies to filter by
                                    Optional

        :param  [str]   quote:      Comma separated list of quote currencies to filter by 
                                    Optional   
        '''

        url = self.client.get_url('markets')
        params = {
            'exchange': exchange,
            'base': base,
            'quote': quote
        }

        resp = requests.get(url, params = params)

        if resp.status_code == 200:
            return resp.json()
        else:
            return resp.text

    def get_market_cap_history(self, start, end = None):
        '''
        Returns the total market cap for all cryptoassets at intervals between the requested time period.

        :param  str start:  Start time of the interval in RFC3339 format

        :param  str end:    End time of the interval in RFC3339 format. If not provided, the current time is used.  
        '''

        url = self.client.get_url('market-cap/history')
        params = {
            'start': start,
            'end': end
        }
        
        resp = requests.get(url, params = params)

        if resp.status_code == 200:
            return resp.json()
        else:
            return resp.text

    def get_exchange_markets_ticker(self, interval = None, currency = None, base = None, quote = None, exchange = None, market = None, convert = None):
        '''
        Returns high level information about individual markets on exchanges integrated with Nomics.

        :param  [str]   interval:   Comma separated time interval of the ticker(s). 
                                    Default is 1d,7d,30d,365d,ytd

        :param  [str]   currency:   A comma separated list of Nomics Currency IDs.

        :param  [str]   base:       A comma separated list of Nomics Currency IDs.

        :param  [str]   quote:      A comma separated list of Nomics Currency IDs. 

        :param  [str]   exchange:   A comma separated list of Nomics Exchange IDs.

        :param  [str]   market:     A comma separated list of Nomics Market IDs.

        :param  str     convert:    Nomics Currency ID to convert all financial data to     
        '''

        url = self.client.get_url('exchange-markets/ticker')
        params = {
            'interval': interval,
            'currency': currency,
            'base': base,
            'quote': quote,
            'exchange': exchange,
            'market': market,
            'convert': convert
        }
        
        resp = requests.get(url, params = params)

        if resp.status_code == 200:
            return resp.json()
        else:
            return resp.text



import pytest

from config import NOMICS_API_KEY
from nomics import Nomics

@pytest.fixture
def nomics():
    return Nomics(NOMICS_API_KEY)

def test_get_currencies(nomics):
    data = nomics.Currencies.get_currencies(ids = ["BTC", 'ETC'])
    assert isinstance(data, list)
    assert len(data) == 2

def test_get_metadata(nomics):
    data = nomics.Currencies.get_metadata(ids = ["BTC"])
    assert isinstance(data, list)
    assert len(data) > 0

def test_get_sparkline(nomics):
    data = nomics.Currencies.get_sparkline(start = "2020-04-01T00:00:00Z")
    assert isinstance(data, list)
    assert len(data) > 0

def test_get_supplies_interval(nomics):
    data = nomics.Currencies.get_supplies_interval(start = "2018-04-14T00:00:00Z")
    assert isinstance(data, list)
    assert len(data) > 0


import requests

from .api import API

class ExchangeRates(API):
    def get_rates(self, format = None):
        '''
        Returns the current exchange rates used by Nomics to convert prices from markets into USD. 
        This contains Fiat currencies as well as a BTC and ETH quote prices.

        :param  str format: Format of the response. Defaults to JSON when blank.

        '''

        url = self.client.get_url('exchange-rates')
        params = {
            'format': format
        }

        resp = requests.get(url, params = params)

        if resp.status_code == 200:
            return resp.json()
        else:
            return resp.text

    def get_history(self, currency, start, end = None):
        '''
        Returns exchange rates for every point in a time range.

        :param  str     currency:   Currency ID

        :param  str     start:      Start time of the interval in RFC3339 format

        :param  str     end:        End time of the interval in RFC3339 format. If not provided, the current time is used. 
        '''

        url = self.client.get_url('exchange-rates/history')
        params = {
            'currency': currency,
            'start': start,
            'end': end
        }

        resp = requests.get(url, params = params)

        if resp.status_code == 200:
            return resp.json()
        else:
            return resp.text


import requests

from .api import API

class Volume(API):
    def get_volume_history(self, start = None, end = None):
        '''
        Returns the total volume for all cryptoassets in USD at intervals between the requested time period.

        :param  str start:  Start time of the interval in RFC3339 format

        :param  str end:    End time of the interval in RFC3339 format. If not provided, the current time is used.  
        '''

        url = self.client.get_url('volume/history')
        params = {
            'start': start,
            'end': end
        }
        
        resp = requests.get(url, params = params)

        if resp.status_code == 200:
            return resp.json()
        else:
            return resp.text


import requests

from .api import API

class Currencies(API):
    def get_currencies(self, ids = None, interval = None, convert = None, include_transparency = False):
        '''
        Returns price, volume, market cap, and rank for all currencies

        :param  [str]   ids:                    Comma separated list of Nomics Currency IDs 
                                                to filter result rows. Optional

        :param  [str]   interval:               Comma separated time interval of the ticker(s). 
                                                Default is 1d,7d,30d,365d,ytd

        :param  str     convert:                Currency to quote ticker price, market cap, and volume values. 
                                                May be a Fiat Currency or Cryptocurrency. 
                                                Default is USD.     
        :param  bool    include-transparency:   Whether to include Transparent Volume information for currencies. 
                                                Default is false. Only available to paid API plans
        '''

        url = self.client.get_url('currencies/ticker')
        params = {
            'ids': ', '.join(ids), #ids has to be comma separated
            'interval': interval,
            'convert': convert,
            'include-transparency': include_transparency
        }

        resp = requests.get(url, params = params)

        if resp.status_code == 200:
            return resp.json()
        else:
            return resp.text

    def get_metadata(self, ids = None, attributes = None):
        '''
        Returns  all the currencies and their metadata that Nomics supports

        :param  [str]   ids:        Comma separated list of Nomics Currency IDs 
                                    to filter result rows. Optional

        :param  [str]   attributes: Comma separated list of currency attributes to filter result columns
                                    Optional
        '''

        url = self.client.get_url('currencies')
        params = {
            'ids': ids,
            'attributes': attributes
        }

        resp = requests.get(url, params = params)

        if resp.status_code == 200:
            return resp.json()
        else:
            return resp.text

    def get_sparkline(self, start, end = None):
        '''
        Returns prices for all currencies within a customizable time interval suitable for sparkline charts.

        :param  str start:  Start time of the interval in RFC3339 format

        :param  str end:    End time of the interval in RFC3339 format. If not provided, the current time is used.
        '''

        url = self.client.get_url('currencies/sparkline')
        params = {
            'start': start,
            'end': end
        }
        
        resp = requests.get(url, params = params)

        if resp.status_code == 200:
            return resp.json()
        else:
            return resp.text

    def get_supplies_interval(self, start, end = None):
        '''
        Returns the open and close suplly information for all currencies between a customizable time interval

        :param  str start:  Start time of the interval in RFC3339 format

        :param  str end:    End time of the interval in RFC3339 format. If not provided, the current time is used.
        '''

        url = self.client.get_url('supplies/interval')
        params = {
            'start': start,
            'end': end
        }

        resp = requests.get(url, params = params)

        if resp.status_code == 200:
            return resp.json()
        else:
            return resp.text


import pytest

from config import NOMICS_API_KEY
from nomics import Nomics

@pytest.fixture
def nomics():
    return Nomics(NOMICS_API_KEY)

def test_get_url(nomics):
    assert nomics.get_url('currencies') == "https://api.nomics.com/v1/currencies?key={}".format(NOMICS_API_KEY)





name = "nomics-python"

import json

from nomics.api import (
    Candles,
    Currencies,
    ExchangeRates,
    Markets,
    Volume
)

class Nomics:
    def __init__(self, key):
        self.key = key

        self.Candles = Candles(self)
        self.Currencies = Currencies(self)
        self.ExchangeRates = ExchangeRates(self)
        self.Markets = Markets(self)
        self.Volume = Volume(self)

    def get_url(self, endpoint):
        return "https://api.nomics.com/v1/{}?key={}".format(endpoint, self.key)




import pytest

from config import NOMICS_API_KEY
from nomics import Nomics

@pytest.fixture
def nomics():
    return Nomics(NOMICS_API_KEY)

def test_get_aggregated_candles(nomics):
    data = nomics.Candles.get_candles(interval = "1d", base = "BTC")
    assert isinstance(data, list)
    assert len(data) > 0

def test_get_exchange_candles(nomics):
    data = nomics.Candles.get_candles(interval = "1d", base = "BTC", quote = 'USDT', exchange = 'binance')
    assert isinstance(data, list)
    assert len(data) > 0

# Add back in when I get access to this API
'''def test_get_aggregated_candles_pair(nomics):
    data = nomics.Candles.get_candles(interval = "1d", base = "BTC", quote = "USDT")
    assert isinstance(data, list)
    assert len(data) > 0'''


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name = "nomics-python",
    version = "3.0.4",
    author = "Taylor Facen",
    author_email = "taylor.facen@gmail.com",
    description = "A python wrapper for the Nomics API",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    url = "https://github.com/TaylorFacen/nomics-python",
    packages = setuptools.find_packages(),
    install_requires = ['requests>=2'],
    classifiers = [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License"
    ]
)


import logging
import pytest

from config import NOMICS_API_KEY
from nomics import Nomics

@pytest.fixture
def nomics():
    return Nomics(NOMICS_API_KEY)

def test_get_volume_history(nomics):
    data = nomics.Volume.get_volume_history()
    assert isinstance(data, list)
    assert len(data) > 0